@@ -2,16 +2,19 @@ from pycirclize.utils import plot
 from pycirclize.utils.dataset import (
     fetch_genbank_by_accid,
     load_eukaryote_example_dataset,
+    load_example_image_file,
     load_prokaryote_example_file,
 )
-from pycirclize.utils.plot import ColorCycler
+from pycirclize.utils.helper import ColorCycler, calc_group_spaces
 from pycirclize.utils.tree import TreeUtil
 
 __all__ = [
+    "plot",
     "fetch_genbank_by_accid",
     "load_eukaryote_example_dataset",
     "load_prokaryote_example_file",
-    "plot",
+    "load_example_image_file",
     "ColorCycler",
+    "calc_group_spaces",
     "TreeUtil",
 ]
