@@ -4,7 +4,6 @@ from pathlib import Path
 
 import numpy as np
 import pandas as pd
-import pytest
 from Bio import Phylo
 
 from pycirclize import Circos
@@ -19,24 +18,6 @@ np.random.seed(0)
 random.seed(0)
 
 
-@pytest.fixture
-def fig_outfile(tmp_path: Path) -> Path:
-    """Figure output file fixture"""
-    return tmp_path / "figure.png"
-
-
-@pytest.fixture
-def hg38_testdata_dir(testdata_dir: Path):
-    """hg38 dataset directory fixture"""
-    return testdata_dir / "eukaryote" / "hg38"
-
-
-@pytest.fixture
-def prokaryote_testdata_dir(testdata_dir: Path):
-    """Prokaryote test file directory"""
-    return testdata_dir / "prokaryote"
-
-
 ###########################################################
 # Circos Class Plot
 ###########################################################
